CPWindow1::CPWindow1(void)
{
  SetFOwner(this);
  SetClass(lxT("CPWindow"));
  SetName(lxT("window1"));
  SetTag(0);
  SetX(314);
  SetY(192);
  SetWidth(600);
  SetHeight(400);
  SetHint(lxT(""));
  SetEnable(1);
  SetVisible(1);
  SetPopupMenu(NULL);
  SetTitle(lxT("motor"));
  SetOverrideRedirect(0);
  //edit1
  edit1.SetFOwner(this);
  edit1.SetClass(lxT("CEdit"));
  edit1.SetName(lxT("edit1"));
  edit1.SetTag(0);
  edit1.SetX(497);
  edit1.SetY(61);
  edit1.SetWidth(80);
  edit1.SetHeight(25);
  edit1.SetHint(lxT(""));
  edit1.SetEnable(1);
  edit1.SetVisible(1);
  edit1.SetPopupMenu(NULL);
  edit1.SetText(lxT("0"));
  edit1.SetReadOnly(0);
  CreateChild(&edit1);
  //edit2
  edit2.SetFOwner(this);
  edit2.SetClass(lxT("CEdit"));
  edit2.SetName(lxT("edit2"));
  edit2.SetTag(0);
  edit2.SetX(498);
  edit2.SetY(109);
  edit2.SetWidth(80);
  edit2.SetHeight(25);
  edit2.SetHint(lxT(""));
  edit2.SetEnable(1);
  edit2.SetVisible(1);
  edit2.SetPopupMenu(NULL);
  edit2.SetText(lxT("0"));
  edit2.SetReadOnly(0);
  CreateChild(&edit2);
  //edit3
  edit3.SetFOwner(this);
  edit3.SetClass(lxT("CEdit"));
  edit3.SetName(lxT("edit3"));
  edit3.SetTag(0);
  edit3.SetX(497);
  edit3.SetY(195);
  edit3.SetWidth(80);
  edit3.SetHeight(25);
  edit3.SetHint(lxT(""));
  edit3.SetEnable(1);
  edit3.SetVisible(1);
  edit3.SetPopupMenu(NULL);
  edit3.SetText(lxT("0"));
  edit3.SetReadOnly(0);
  CreateChild(&edit3);
  //edit4
  edit4.SetFOwner(this);
  edit4.SetClass(lxT("CEdit"));
  edit4.SetName(lxT("edit4"));
  edit4.SetTag(0);
  edit4.SetX(497);
  edit4.SetY(228);
  edit4.SetWidth(80);
  edit4.SetHeight(25);
  edit4.SetHint(lxT(""));
  edit4.SetEnable(1);
  edit4.SetVisible(1);
  edit4.SetPopupMenu(NULL);
  edit4.SetText(lxT("0"));
  edit4.SetReadOnly(0);
  CreateChild(&edit4);
  //edit5
  edit5.SetFOwner(this);
  edit5.SetClass(lxT("CEdit"));
  edit5.SetName(lxT("edit5"));
  edit5.SetTag(0);
  edit5.SetX(499);
  edit5.SetY(313);
  edit5.SetWidth(80);
  edit5.SetHeight(25);
  edit5.SetHint(lxT(""));
  edit5.SetEnable(1);
  edit5.SetVisible(1);
  edit5.SetPopupMenu(NULL);
  edit5.SetText(lxT("0"));
  edit5.SetReadOnly(0);
  CreateChild(&edit5);
  //button1
  button1.SetFOwner(this);
  button1.SetClass(lxT("CButton"));
  button1.SetName(lxT("button1"));
  button1.SetTag(0);
  button1.SetX(82);
  button1.SetY(82);
  button1.SetWidth(90);
  button1.SetHeight(25);
  button1.SetHint(lxT(""));
  button1.SetEnable(1);
  button1.SetVisible(1);
  button1.SetPopupMenu(NULL);
  button1.EvMouseButtonPress=EVMOUSEBUTTONPRESS & CPWindow1::button1_EvMouseButtonPress;
  button1.SetText(lxT("Configurar"));
  CreateChild(&button1);
  //button2
  button2.SetFOwner(this);
  button2.SetClass(lxT("CButton"));
  button2.SetName(lxT("button2"));
  button2.SetTag(0);
  button2.SetX(83);
  button2.SetY(138);
  button2.SetWidth(90);
  button2.SetHeight(25);
  button2.SetHint(lxT(""));
  button2.SetEnable(1);
  button2.SetVisible(1);
  button2.SetPopupMenu(NULL);
  button2.EvMouseButtonPress=EVMOUSEBUTTONPRESS & CPWindow1::button2_EvMouseButtonPress;
  button2.SetText(lxT("Conectar"));
  CreateChild(&button2);
  //button3
  button3.SetFOwner(this);
  button3.SetClass(lxT("CButton"));
  button3.SetName(lxT("button3"));
  button3.SetTag(0);
  button3.SetX(84);
  button3.SetY(195);
  button3.SetWidth(90);
  button3.SetHeight(25);
  button3.SetHint(lxT(""));
  button3.SetEnable(1);
  button3.SetVisible(1);
  button3.SetPopupMenu(NULL);
  button3.EvMouseButtonPress=EVMOUSEBUTTONPRESS & CPWindow1::button3_EvMouseButtonPress;
  button3.SetText(lxT("Desconectar"));
  CreateChild(&button3);
  //button4
  button4.SetFOwner(this);
  button4.SetClass(lxT("CButton"));
  button4.SetName(lxT("button4"));
  button4.SetTag(0);
  button4.SetX(80);
  button4.SetY(308);
  button4.SetWidth(80);
  button4.SetHeight(25);
  button4.SetHint(lxT(""));
  button4.SetEnable(1);
  button4.SetVisible(1);
  button4.SetPopupMenu(NULL);
  button4.EvMouseButtonPress=EVMOUSEBUTTONPRESS & CPWindow1::button4_EvMouseButtonPress;
  button4.SetText(lxT("Zerar"));
  CreateChild(&button4);
  //button5
  button5.SetFOwner(this);
  button5.SetClass(lxT("CButton"));
  button5.SetName(lxT("button5"));
  button5.SetTag(0);
  button5.SetX(271);
  button5.SetY(82);
  button5.SetWidth(90);
  button5.SetHeight(25);
  button5.SetHint(lxT(""));
  button5.SetEnable(1);
  button5.SetVisible(1);
  button5.SetPopupMenu(NULL);
  button5.EvMouseButtonPress=EVMOUSEBUTTONPRESS & CPWindow1::button5_EvMouseButtonPress;
  button5.SetText(lxT("m esquerda"));
  CreateChild(&button5);
  //button6
  button6.SetFOwner(this);
  button6.SetClass(lxT("CButton"));
  button6.SetName(lxT("button6"));
  button6.SetTag(0);
  button6.SetX(376);
  button6.SetY(82);
  button6.SetWidth(90);
  button6.SetHeight(25);
  button6.SetHint(lxT(""));
  button6.SetEnable(1);
  button6.SetVisible(1);
  button6.SetPopupMenu(NULL);
  button6.EvMouseButtonPress=EVMOUSEBUTTONPRESS & CPWindow1::button6_EvMouseButtonPress;
  button6.SetText(lxT("m direita"));
  CreateChild(&button6);
  //button7
  button7.SetFOwner(this);
  button7.SetClass(lxT("CButton"));
  button7.SetName(lxT("button7"));
  button7.SetTag(0);
  button7.SetX(273);
  button7.SetY(203);
  button7.SetWidth(90);
  button7.SetHeight(25);
  button7.SetHint(lxT(""));
  button7.SetEnable(1);
  button7.SetVisible(1);
  button7.SetPopupMenu(NULL);
  button7.EvMouseButtonPress=EVMOUSEBUTTONPRESS & CPWindow1::button7_EvMouseButtonPress;
  button7.SetText(lxT("m esquerda"));
  CreateChild(&button7);
  //button8
  button8.SetFOwner(this);
  button8.SetClass(lxT("CButton"));
  button8.SetName(lxT("button8"));
  button8.SetTag(0);
  button8.SetX(381);
  button8.SetY(203);
  button8.SetWidth(90);
  button8.SetHeight(25);
  button8.SetHint(lxT(""));
  button8.SetEnable(1);
  button8.SetVisible(1);
  button8.SetPopupMenu(NULL);
  button8.EvMouseButtonPress=EVMOUSEBUTTONPRESS & CPWindow1::button8_EvMouseButtonPress;
  button8.SetText(lxT("m direita"));
  CreateChild(&button8);
  //button9
  button9.SetFOwner(this);
  button9.SetClass(lxT("CButton"));
  button9.SetName(lxT("button9"));
  button9.SetTag(0);
  button9.SetX(328);
  button9.SetY(256);
  button9.SetWidth(100);
  button9.SetHeight(25);
  button9.SetHint(lxT(""));
  button9.SetEnable(1);
  button9.SetVisible(1);
  button9.SetPopupMenu(NULL);
  button9.EvMouseButtonPress=EVMOUSEBUTTONPRESS & CPWindow1::button9_EvMouseButtonPress;
  button9.SetText(lxT("posicionar(2)"));
  CreateChild(&button9);
  //button10
  button10.SetFOwner(this);
  button10.SetClass(lxT("CButton"));
  button10.SetName(lxT("button10"));
  button10.SetTag(0);
  button10.SetX(272);
  button10.SetY(315);
  button10.SetWidth(80);
  button10.SetHeight(25);
  button10.SetHint(lxT(""));
  button10.SetEnable(1);
  button10.SetVisible(1);
  button10.SetPopupMenu(NULL);
  button10.EvMouseButtonPress=EVMOUSEBUTTONPRESS & CPWindow1::button10_EvMouseButtonPress;
  button10.SetText(lxT("sobe"));
  CreateChild(&button10);
  //button11
  button11.SetFOwner(this);
  button11.SetClass(lxT("CButton"));
  button11.SetName(lxT("button11"));
  button11.SetTag(0);
  button11.SetX(390);
  button11.SetY(314);
  button11.SetWidth(80);
  button11.SetHeight(25);
  button11.SetHint(lxT(""));
  button11.SetEnable(1);
  button11.SetVisible(1);
  button11.SetPopupMenu(NULL);
  button11.EvMouseButtonPress=EVMOUSEBUTTONPRESS & CPWindow1::button11_EvMouseButtonPress;
  button11.SetText(lxT("desce"));
  CreateChild(&button11);
  /*#Others*/
}
